.slick-slider{position:relative;display:block;-moz-box-sizing:border-box;box-sizing:border-box;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;-webkit-touch-callout:none;-khtml-user-select:none;-ms-touch-action:pan-y;touch-action:pan-y;-webkit-tap-highlight-color:transparent;}.slick-list{position:relative;display:block;overflow:hidden;margin:0;padding:0;}.slick-list:focus{outline:none;}.slick-list.dragging{cursor:pointer;cursor:hand;}.slick-slider .slick-track,.slick-slider .slick-list{-webkit-transform:translate3d(0,0,0);-moz-transform:translate3d(0,0,0);-ms-transform:translate3d(0,0,0);-o-transform:translate3d(0,0,0);transform:translate3d(0,0,0);}.slick-track{position:relative;top:0;left:0;display:block;}.slick-track:before,.slick-track:after{display:table;content:'';}.slick-track:after{clear:both;}.slick-loading .slick-track{visibility:hidden;}.slick-slide{display:none;float:left;height:100%;min-height:1px;}[dir='rtl'] .slick-slide{float:right;}.slick-slide img{display:block;}.slick-slide.slick-loading img{display:none;}.slick-slide.dragging img{pointer-events:none;}.slick-initialized .slick-slide{display:block;}.slick-loading .slick-slide{visibility:hidden;}.slick-vertical .slick-slide{display:block;height:auto;border:1px solid transparent;}.slick-arrow.slick-hidden{display:none;}.slick-active{z-index:1;right:-1px;}#slider-wrapper{margin-bottom:1.414em;}.slick-slider > button{color:#444;background-color:#fff;min-width:1.5em;min-height:1.5em;padding:0;margin:0;}.slick-slider > button:before{font-size:16px;vertical-align:middle;}.slick-slider > button.slick-next{position:absolute;right:0;top:50%;margin-top:-1.5em;border-top-right-radius:0;border-bottom-right-radius:0;}.slick-slider > button.slick-prev{position:absolute;left:0;top:50%;margin-top:-1.5em;border-top-left-radius:0;border-bottom-left-radius:0;}.slick-slider > button.slick-play{position:absolute;top:0.7em;left:0.7em;}.slick-slider > button.slick-pause{position:absolute;top:0.7em;left:2.9em;}.slick-dots{list-style-type:none;margin:0;padding:0;zoom:1;text-align:center;padding:0.7em 1.2em;}.slick-dots:before,.slick-dots:after{content:" ";display:block;height:0;visibility:hidden;}.slick-dots:after{clear:both;}.slick-dots > li{display:block;}.slick-dots > li > a{display:block;padding:0.7em 1.2em;}.slick-dots > li{float:left;}.slick-dots > li:last-child > a{padding-right:0;}.slick-dots > li:first-child > a{padding-left:0;}.slick-dots > li{display:inline-block;float:none;}.slick-dots > li.slick-active > button{color:#444;border-radius:2px;background-color:#BAAFC4;display:inline-block;padding:0.21em 0.36em;margin:0 0.25em 0.707em 0;border-radius:50%;text-align:center;padding-top:0;padding-bottom:0;margin:0;font-size:0.75rem;min-width:1.5em;height:1.5em;vertical-align:0.7em;line-height:1.5em;margin-right:0.75em;font-size:1em;}.slick-dots > li > button{color:#efefef;border-radius:2px;background-color:#3B234A;display:inline-block;padding:0.21em 0.36em;margin:0 0.25em 0.707em 0;border-radius:50%;text-align:center;padding-top:0;padding-bottom:0;margin:0;font-size:0.75rem;min-width:1.5em;height:1.5em;vertical-align:0.7em;line-height:1.5em;margin-right:0.75em;font-size:1em;}.sliderPane{position:relative;}.sliderText{padding:0.7em 1.2em;position:absolute;bottom:1.5em;left:1.5em;right:30%;background-color:#fff;}.sliderText > p{font-size:16px;}.sliderText > p.title{font-family:"HelveticaNeue-Light","Helvetica Neue Light","Helvetica Neue",Helvetica,Arial,"Lucida Grande",sans-serif;font-weight:bold;font-size:1.728rem;margin-bottom:0.5em;}.arrowsOnHover > button.slick-next,.arrowsOnHover > button.slick-prev{display:none;}.arrowsOnHover:hover > button{display:block;}li.slAction > a.layout_dummy-dummy-slider{background-image:url(++resource++ftw.slider/slider_block.png);background-repeat:no-repeat;background-position:center center;}