$slider-bg-start: $global-navigation-border-color;
$slider-bg-end: darken($slider-bg-start, 10%);
$slider-color: contrast($slider-bg-start, #FFF, #000);

.slick-dots li button:before {
  color: transparent;
}
#content ul.slick-dots li.slick-active {
  background-color: $slider-bg-start;
}
#slider-wrapper .sliderText {
  @include gradient($slider-bg-start, $slider-bg-end);
  color: $slider-color;
  height: 100px;
  width: 50%;
  position: absolute;
  right:0;
  left: auto;
  bottom: 0;
  padding: 1em;
  margin-bottom: 2em;
  overflow: hidden;
  a {
    color: $slider-color;
  }
  > p {
    font-size: 13px;
    margin: 0;
    font-weight: normal;

    &.title {
      margin: 0;
      line-height: 1.5em;
      font-size: 16px;
      font-weight: normal;
    }
  }
}
#slider-panes .slick-prev {
  @include icon($char: "");
}
#slider-panes .slick-next {
  @include icon($char: "");
}
#slider-panes .slick-prev,
#slider-panes .slick-next {
  border: 0;
  margin: 0;
  width: 40px;
  height: 40px;
  background-color: rgba(255, 255, 255, .5);
  &:before {
    font-size: 1.75*($font-size);
    vertical-align: middle;
    color: $link-color;
  }
  &:hover:before {
    color: $link-color-hover;
  }
}

.sliderGallery {
  border: 1px solid #ccc;
  background-color: #eaeaea;

  > button.slick-next, > button.slick-prev {
    position: absolute;
    top: 5px;
    border: 0;
    margin-top: 0;
    background-color: transparent;
  }

  .slick-next {
    right: 10px;
    &:before {
      content: '»';
    }
  }

  .slick-prev {
    left: 10px;
    &:before {
      content: '«';
    }
  }
}

.imgTitle {
  position: absolute;
  top: 0;
  text-align: center;
  left: 0;
  right: 0;
  z-index: 1;
  background-color: rgba(255,255,255,.6);
}

.sl-img-wrapper {
  position: relative;

  img {
    margin: auto;
  }
}

.imgDescription {
  background-color: white;
  text-align: center;
}

.portaltype-subsite .sliderImage {
  margin-bottom: 0;
}

.portaltype-subsite #slider-wrapper {
  margin-bottom: 1em;
}

.sliderImage {
  margin-bottom: 0;
}

.portaltype-plone-site #slider-wrapper .sliderText {
  height: auto;
  min-height: 120px;
  bottom: 0;
  left: 0;
  right: 0;
}

@media screen and (max-width: $screen-tablet) {

    #slider-panes {
      background: $slider-bg-end;
    }
    #container {
      #slider-wrapper, .sliderWrapper {
        .sliderText {
          position: relative;
          padding: 2%;
          box-sizing: border-box;
        }
      }
    }

}
